==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/PStringSegment.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_P_STRING_SEGMENT_H_
#define _D_P_STRING_SEGMENT_H_

#include "PStringDatum.h"

class PStringSegmentVisitor;

typedef SharedHandle<PStringSegmentVisitor> PStringSegmentVisitorHandle;

class PStringSegment : public PStringDatum
{
private:

  string _value;

  PStringDatumHandle _next;

public:
  PStringSegment(const string& value, const PStringDatumHandle& next = 0):
    _value(value), _next(next) {}

  virtual ~PStringSegment() {}

  virtual void accept(const PStringVisitorHandle& visitor);

  const string& getValue() const
  {
    return _value;
  }

  bool hasNext() const
  {
    return !_next.isNull();
  }

  PStringDatumHandle getNext() const
  {
    return _next;
  }
};

typedef SharedHandle<PStringSegment> PStringSegmentHandle;

class PStringSegmentVisitor {
public:
  virtual ~PStringSegmentVisitor() {}

  virtual void hello(PStringSegment* s) = 0;
  
  virtual void goodbye(PStringSegment* s) = 0;
};

typedef SharedHandle<PStringSegmentVisitor> PStringSegmentVisitorHandle;

#endif // _D_P_STRING_SEGMENT_H_

==> aria2-1.8.3.tar.gz: aria2-1.8.3/src/PStringSegment.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_P_STRING_SEGMENT_H_
#define _D_P_STRING_SEGMENT_H_

#include "PStringDatum.h"
#include <string>

namespace aria2 {

class PStringSegment : public PStringDatum
{
private:

  std::string _value;

  SharedHandle<PStringDatum> _next;

public:
  PStringSegment(const std::string& value,
                 const SharedHandle<PStringDatum>& next);

  PStringSegment(const std::string& value);

  virtual ~PStringSegment();

  virtual void accept(PStringVisitor& visitor);

  const std::string& getValue() const;

  bool hasNext() const;

  SharedHandle<PStringDatum> getNext() const;
};

typedef SharedHandle<PStringSegment> PStringSegmentHandle;

} // namespace aria2

#endif // _D_P_STRING_SEGMENT_H_
